@@ -8,7 +8,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-11-10'; # DATE
 our $DIST = 'App-SubtitleUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our @EXPORT_OK = qw(
                        srtparse
@@ -242,7 +242,7 @@ sub srtcombinetext {
                     }
                     no warnings 'once';
                     local $main::entry = $parsed[$j]{entries}[$i];
-                    local $main::j = $j;
+                    local $main::idx = $j;
                     $code->();
                 }
                 $merged_text .= $_;
@@ -276,7 +276,7 @@ App::SubtitleUtils - Utilities related to video subtitles
 
 =head1 VERSION
 
-This document describes version 0.009 of App::SubtitleUtils (from Perl distribution App-SubtitleUtils), released on 2022-11-10.
+This document describes version 0.010 of App::SubtitleUtils (from Perl distribution App-SubtitleUtils), released on 2022-11-10.
 
 =head1 DESCRIPTION
 
